# Migrating from the Fact Sheets REST API to the GraphQL API
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?version=CLOUD#overview)
  * [Before You Start](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?version=CLOUD#before-you-start)
  * [Get All Fact Sheets](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?version=CLOUD#get-all-fact-sheets)
  * [Get a Fact Sheet Hierarchy by Root ID](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?version=CLOUD#get-a-fact-sheet-hierarchy-by-root-id)
  * [Get a Fact Sheet by ID](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?version=CLOUD#get-a-fact-sheet-by-id)
  * [Get All Relations of a Fact Sheet](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?version=CLOUD#get-all-relations-of-a-fact-sheet)
  * [Create a Fact Sheet](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?version=CLOUD#create-a-fact-sheet)
  * [Update a Fact Sheet](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api?version=CLOUD#update-a-fact-sheet)


View all
Mappings of REST API endpoints to GraphQL queries and mutations.
